import { AttachmentTypes } from "./message";
import { textSuperScript } from "./utils";

function timestampToTime(timestamp) {
  const date = new Date(timestamp * 1000);
  const min = date.getMinutes().toString(10);
  const sec = date.getSeconds().toString(10);
  return `${min.padStart(2, "0")}:${sec.padStart(2, "0")}`;
}

export function getMessageIcon(msg) {
  if (msg.icon) {
    return msg.icon;
  }
  const icons = {};
  msg.attachments.forEach(at => {
    switch (at.type) {
      case AttachmentTypes.ANIMATION:
        icons["🏄"] = true;
        break;
      case AttachmentTypes.AUDIO:
        icons["🎵"] = true;
        break;
      case AttachmentTypes.CONTACT:
        icons["☎️"] = true;
        break;
      case AttachmentTypes.DOCUMENT:
        icons["📁"] = true;
        break;
      case AttachmentTypes.LINK:
        icons["🔗"] = true;
        break;
      case AttachmentTypes.LOCATION:
        icons["🌎"] = true;
        break;
      case AttachmentTypes.PHOTO:
        icons["🖼"] = true;
        break;
      case AttachmentTypes.STICKER:
        icons["🗯"] = true;
        break;
      case AttachmentTypes.VIDEO:
        icons["🎬"] = true;
        break;
      case AttachmentTypes.VOICE:
        icons["🎤"] = true;
        break;
    }
  });
  if (Object.keys(icons).length > 0) {
    return Object.keys(icons).join("");
  }
  return "💬";
}

export function formatBadge(provider, profile, date) {
  let badge = ["➜"];

  if (profile && profile.fullname) {
    badge.push(profile.fullname);
  }

  badge.push(textSuperScript("("));
  if (provider) {
    badge.push(textSuperScript(provider));
  }

  if (profile && profile.username) {
    badge.push(textSuperScript(profile.username));
  }
  if (date) {
    badge.push(textSuperScript(timestampToTime(date)));
  }
  badge.push(textSuperScript(")"));
  return badge.join(" ");
}

export function format(msg, options) {
  const opts = Object.assign(
    {},
    {
      text: true,
      badge: true
    },
    options
  );
  let message = "";

  if (opts.badge) {
    message = `${getMessageIcon(msg)}${formatBadge(
      msg.provider,
      msg.profile,
      msg.date
    )}`;
    if (opts.text && msg.text) {
      message += `:\n${msg.text}`;
    }
  } else if (opts.text && msg.text) {
    message = msg.text;
  }
  return message;
}
