import randomString from "crypto-random-string";
import { Op, Chat, Connection } from "./db";

export const LRU_CACHE_MAXAGE = 10 * 60 * 60 * 1000;

export async function getChat(provider, providerChatId) {
  const chat = await Chat.findOrCreate({
    where: {
      provider,
      providerChatId
    }
  });
  return chat[0];
}

export async function createConnection(chat) {
  const chatConnection = await Connection.create({
    key: randomString(20)
  });
  await chatConnection.setLeftChat(chat);
  return `${chatConnection.id}!${chatConnection.key}`;
}

export async function findConnection(id) {
  return Connection.findOne({
    where: {
      id
    }
  });
}

export async function findConnectionsForChatId(chatId, activeOnly = true) {
  const clause = [
    {
      [Op.or]: [{ leftChatId: chatId }, { rightChatId: chatId }]
    }
  ];
  if (activeOnly) {
    clause.push({
      direction: {
        [Op.ne]: "NONE"
      }
    });
    clause.push({
      leftChatId: { [Op.ne]: null }
    });
    clause.push({
      rightChatId: { [Op.ne]: null }
    });
  }
  return Connection.findAll({
    include: [
      {
        model: Chat,
        as: "leftChat"
      },
      {
        model: Chat,
        as: "rightChat"
      }
    ],
    where: {
      [Op.and]: clause
    }
  });
}

export function textSuperScript(text) {
  var map = {
    "0": "⁰",
    "1": "¹",
    "2": "²",
    "3": "³",
    "4": "⁴",
    "5": "⁵",
    "6": "⁶",
    "7": "⁷",
    "8": "⁸",
    "9": "⁹",
    a: "ᵃ",
    b: "ᵇ",
    c: "ᶜ",
    d: "ᵈ",
    e: "ᵉ",
    f: "ᶠ",
    g: "ᵍ",
    h: "ʰ",
    i: "ᶦ",
    j: "ʲ",
    k: "ᵏ",
    l: "ˡ",
    m: "ᵐ",
    n: "ⁿ",
    o: "ᵒ",
    p: "ᵖ",
    q: "ᑫ",
    r: "ʳ",
    s: "ˢ",
    t: "ᵗ",
    u: "ᵘ",
    v: "ᵛ",
    w: "ʷ",
    x: "ˣ",
    y: "ʸ",
    z: "ᶻ",
    A: "ᴬ",
    B: "ᴮ",
    C: "ᶜ",
    D: "ᴰ",
    E: "ᴱ",
    F: "ᶠ",
    G: "ᴳ",
    H: "ᴴ",
    I: "ᴵ",
    J: "ᴶ",
    K: "ᴷ",
    L: "ᴸ",
    M: "ᴹ",
    N: "ᴺ",
    O: "ᴼ",
    P: "ᴾ",
    R: "ᴿ",
    S: "ˢ",
    T: "ᵀ",
    U: "ᵁ",
    V: "ⱽ",
    W: "ᵂ",
    X: "ˣ",
    Y: "ʸ",
    Z: "ᶻ",
    "+": "⁺",
    "-": "⁻",
    "=": "⁼",
    "(": "⁽",
    ")": "⁾",
    ":": "˸",
    q: "ᵠ",
    Q: "ᵠ",
    "?": "ˀ",
    "!": "ᵎ"
  };
  var charArray = text.split("");
  for (var i = 0; i < charArray.length; i++) {
    if (map[charArray[i].toLowerCase()]) {
      charArray[i] = map[charArray[i]];
    }
  }
  text = charArray.join("");
  return text;
}
